==> Heatplus_1.10.0.zip: Heatplus/doc/Heatplus.R <==
###################################################
### chunk number 1: 
###################################################
options(width=65)


###################################################
### chunk number 2: 
###################################################
mm = matrix(rnorm(1000, m=1), 100,10)
mm = cbind(mm, matrix(rnorm(2000), 100, 20))
mm = cbind(mm, matrix(rnorm(1500, m=-1), 100, 15))
mm2 = matrix(rnorm(450), 30, 15)
mm2 = cbind(mm2, matrix(rnorm(900,m=1.5), 30,30))
mm=rbind(mm, mm2)
colnames(mm) = paste("Sample", 1:45)
rownames(mm) = paste("Gene", 1:130)


###################################################
### chunk number 3: 
###################################################
addvar = data.frame(Var1=rep(c(0,1,0),c(10,20,15)),
                    Var2=rep(c(1,0,0),c(10,20,15)), 
					Var3=rep(c(1,0), c(15,30)), 
					Var4=rep(seq(0,1,length=4), c(10,5,15,15))+rnorm(45,sd=0.5))
addvar[3,3] = addvar[17,2] = addvar[34,1] =NA


###################################################
### chunk number 4: 
###################################################
library(Heatplus)
heatmap_2(mm)


###################################################
### chunk number 5: 
###################################################
heatmap_2(mm, do.dendro=c(FALSE, TRUE), legend=1, legfrac=12)


###################################################
### chunk number 6: 
###################################################
heatmap_plus(mm)


###################################################
### chunk number 7: 
###################################################
colnames(mm) = NULL
heatmap_plus(mm, addvar=addvar, cov=4)


###################################################
### chunk number 8: 
###################################################
heatmap_plus(mm, addvar=addvar, cov=4, h=20, col=RGBColVec(64))

==> Heatplus_1.20.0.zip: Heatplus/doc/Heatplus.R <==
###################################################
### chunk number 1: 
###################################################
#line 45 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpH0ah73/R.INSTALL794f7739/Heatplus/inst/doc/Heatplus.Rnw"
options(width=65)


###################################################
### chunk number 2: 
###################################################
#line 52 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpH0ah73/R.INSTALL794f7739/Heatplus/inst/doc/Heatplus.Rnw"
mm = matrix(rnorm(1000, m=1), 100,10)
mm = cbind(mm, matrix(rnorm(2000), 100, 20))
mm = cbind(mm, matrix(rnorm(1500, m=-1), 100, 15))
mm2 = matrix(rnorm(450), 30, 15)
mm2 = cbind(mm2, matrix(rnorm(900,m=1.5), 30,30))
mm=rbind(mm, mm2)
colnames(mm) = paste("Sample", 1:45)
rownames(mm) = paste("Gene", 1:130)


###################################################
### chunk number 3: 
###################################################
#line 65 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpH0ah73/R.INSTALL794f7739/Heatplus/inst/doc/Heatplus.Rnw"
addvar = data.frame(Var1=rep(c(0,1,0),c(10,20,15)),
                    Var2=rep(c(1,0,0),c(10,20,15)), 
					Var3=rep(c(1,0), c(15,30)), 
					Var4=rep(seq(0,1,length=4), c(10,5,15,15))+rnorm(45,sd=0.5))
addvar[3,3] = addvar[17,2] = addvar[34,1] =NA


###################################################
### chunk number 4: 
###################################################
#line 79 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpH0ah73/R.INSTALL794f7739/Heatplus/inst/doc/Heatplus.Rnw"
library(Heatplus)
heatmap_2(mm)


###################################################
### chunk number 5: 
###################################################
#line 89 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpH0ah73/R.INSTALL794f7739/Heatplus/inst/doc/Heatplus.Rnw"
heatmap_2(mm, do.dendro=c(FALSE, TRUE), legend=1, legfrac=12)


###################################################
### chunk number 6: 
###################################################
#line 98 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpH0ah73/R.INSTALL794f7739/Heatplus/inst/doc/Heatplus.Rnw"
heatmap_plus(mm)


###################################################
### chunk number 7: 
###################################################
#line 107 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpH0ah73/R.INSTALL794f7739/Heatplus/inst/doc/Heatplus.Rnw"
colnames(mm) = NULL
heatmap_plus(mm, addvar=addvar, cov=4)


###################################################
### chunk number 8: 
###################################################
#line 117 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpH0ah73/R.INSTALL794f7739/Heatplus/inst/doc/Heatplus.Rnw"
heatmap_plus(mm, addvar=addvar, cov=4, h=20, col=RGBColVec(64))
